@@ -30,7 +30,7 @@ class AnthropicConfig(BaseConfig):
         self.client = anthropic.Anthropic(api_key=apiKey)
 
     def _setModels(self):
-        self.RModel = os.getenv("ANTHROPIC_TEXT_MODEL", "claude-sonnet-4")
+        self.RModel = os.getenv("ANTHROPIC_TEXT_MODEL", "claude-3-5-haiku-latest")
         self.VModel = os.getenv("ANTHROPIC_VISION_MODEL", "claude-sonnet-4")
 
     # ---------------------------------------------------------
@@ -56,6 +56,11 @@ class AnthropicConfig(BaseConfig):
         if tools:
             args["tools"] = tools
 
+        if skills:
+            additionalInfo = self.executeSkills(skills, user, tokens, verbose)
+            if additionalInfo:
+                messages.append(formatJsonInput("user", additionalInfo))
+
         if supportsReasoning(model):
             if effort == "auto":
                 budget = 1024
@@ -75,6 +80,8 @@ class AnthropicConfig(BaseConfig):
             args["thinking"] = {"type": "enabled", "budget_tokens": budget}
         
         response = self.client.messages.create(**args)
+        if supportsReasoning(model):
+            return response if verbose else next((block.text for block in response.content if getattr(block, "type", None) == "text"), "")
         return response if verbose else response.content[0].text
 
     # ---------------------------------------------------------
@@ -122,6 +129,14 @@ class AnthropicConfig(BaseConfig):
         response = self.client.messages.create(**args)
         return response if verbose else response.content[0].text
 
+    def processSkills(self, instructions, user, tokens) -> str:
+        messages = []
+        intent = self.extractIntent(user)
+        messages.append(formatJsonInput("user", intent))
+        args = self._getArgs(self.RModel, instructions, messages, tokens)
+        response = self.client.messages.create(**args)
+        return response.content[0].text
+
     def _getArgs(self, model, system, messages, tokens):
         args = {
             "model": model,
