@@ -1,6 +1,7 @@
 import os
 import threading
 import base64
+from tkinter import SE
 from dotenv import load_dotenv
 from google import genai
 from google.genai import types
@@ -60,6 +61,11 @@ class GoogleConfig(BaseConfig):
         if tools:
             configArgs["tools"] = tools
 
+        if skills:
+            additionalInfo = self.executeSkills(skills, user, tokens, verbose)
+            if additionalInfo:
+                messages.append(formatTypedInput("user", additionalInfo))
+
         # --- Only add reasoning config if the model supports it ---
         if supportsReasoning(model):
             if effort == "auto":
@@ -118,6 +124,19 @@ class GoogleConfig(BaseConfig):
         response = self.client.models.generate_content(**args)
         return response if verbose else response.text
 
+    def processSkills(self, instructions, user, tokens) -> str:
+        intent = self.extractIntent(user)
+        messages = [formatTypedInput("user", intent)]
+        configArgs = {
+            "response_mime_type": "text/plain",
+            "system_instruction": [instructions],
+            "max_output_tokens": tokens,
+        }
+        generateConfig = types.GenerateContentConfig(**configArgs)
+        args = self._getArgs(self.RModel, messages, generateConfig)
+        response = self.client.models.generate_content(**args)
+        return response.text
+
     def _getArgs(self, model, messages, config):
         args = {
             "model": model,
