@@ -31,7 +31,7 @@ class GroqConfig(BaseConfig):
         self.client = Groq(api_key=apiKey)
 
     def _setModels(self):
-        self.RModel = os.getenv("GROQ_RESPONSE_MODEL", "llama-3.3-70b-versatile")
+        self.RModel = os.getenv("GROQ_RESPONSE_MODEL", "llama-3.1-8b-instant")
         self.VModel = os.getenv("GROQ_VISION_MODEL", "meta-llama/llama-4-scout-17b-16e-instruct")
 
     # ---------------------------------------------------------
@@ -64,6 +64,11 @@ class GroqConfig(BaseConfig):
             #args["tool_choice"] = toolChoice
             args["tool_choice"] = "auto"  # Always set to auto if tools are provided
 
+        if skills:
+            additionalInfo = self.executeSkills(skills, user, tokens, verbose)
+            if additionalInfo:
+                messages.append(formatJsonInput("user", additionalInfo))
+
         # -- Only add reasoning config if the model supports it --
         if supportsReasoning(model):
             args["reasoning_format"] = show  # "parsed", "raw", or "hidden"
@@ -113,6 +118,15 @@ class GroqConfig(BaseConfig):
         response = self.client.chat.completions.create(**args)
         return response if verbose else response.choices[0].message.content
 
+    def processSkills(self, instructions, user, tokens) -> str:
+        messages = []
+        messages.append(formatJsonInput("system", instructions))
+        intent = self.extractIntent(user)
+        messages.append(formatJsonInput("user", intent))
+        args = self._getArgs(self.RModel, messages, tokens)
+        response= self.client.chat.completions.create(**args)
+        return response.choices[0].message.content
+
     def _getArgs(self, model, messages, tokens):
         args = {
             "model": model,
