@@ -1,4 +1,7 @@
-﻿import os
+﻿
+# OpenAIConfig.py in The HoloAI project is a configuration class for interacting with the OpenAI API.
+
+import os
 import threading
 from dotenv import load_dotenv
 from openai import OpenAI
@@ -30,7 +33,7 @@ class OpenAIConfig(BaseConfig):
         self.client = OpenAI(api_key=apiKey)
 
     def _setModels(self):
-        self.RModel = os.getenv("OPENAI_RESPONSE_MODEL", "gpt-4.1")
+        self.RModel = os.getenv("OPENAI_RESPONSE_MODEL", "gpt-4.1-mini")
         self.VModel = os.getenv("OPENAI_VISION_MODEL", "gpt-4.1")
 
     # ---------------------------------------------------------
@@ -61,6 +64,11 @@ class OpenAIConfig(BaseConfig):
         if tools:
             args["tools"] = tools
 
+        if skills:
+            additionalInfo = self.executeSkills(skills, user, tokens, verbose)
+            if additionalInfo:
+                messages.append(formatJsonInput("user", additionalInfo))
+
         # -- Only add reasoning config if the model supports it --
         if supportsReasoning(model):
             if effort == "auto":
@@ -112,6 +120,15 @@ class OpenAIConfig(BaseConfig):
         response = self.client.responses.create(**args)
         return response if verbose else response.output_text
 
+    def processSkills(self, instructions, user, tokens) -> str:
+        messages = []
+        messages.append(formatJsonInput("system", instructions))
+        intent = self.extractIntent(user)
+        messages.append(formatJsonInput("user", intent))
+        args = self._getArgs(self.RModel, messages, tokens)
+        response= self.client.responses.create(**args).output_text
+        return response
+
     def _getArgs(self, model, messages, tokens):
         args = {
             "model": model,
