@@ -10,6 +10,7 @@ from SynLrn import SynLrn as HoloLrn
 from BitSig import BitSig as HoloLog
 from MediaCapture import MediaCapture as HoloCapture
 from AgentToAgent import AgentToAgent as HoloRelay
+from HoloEcho import HoloEcho
 
 __all__ = [
     "HoloAI",
@@ -21,4 +22,5 @@ __all__ = [
     "HoloViro",
     "HoloRelay",
     "HoloCapture",
+    "HoloEcho",
 ]
